# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_media_contentrestrictions

__all__ = [
    "ContentAccessRestrictionLevel",
    "RatedContentCategory",
    "ContentRestrictionsBrowsePolicy",
    "RatedContentDescription",
    "RatedContentRestrictions",
]

class ContentAccessRestrictionLevel(enum.IntEnum):
    ALLOW = 0
    WARN = 1
    BLOCK = 2
    HIDE = 3

class RatedContentCategory(enum.IntEnum):
    GENERAL = 0
    APPLICATION = 1
    GAME = 2
    MOVIE = 3
    TELEVISION = 4
    MUSIC = 5

ContentRestrictionsBrowsePolicy = _winrt_windows_media_contentrestrictions.ContentRestrictionsBrowsePolicy
RatedContentDescription = _winrt_windows_media_contentrestrictions.RatedContentDescription
RatedContentRestrictions = _winrt_windows_media_contentrestrictions.RatedContentRestrictions
